@@ -1,4 +1,3 @@
-import hashlib
 import json
 import logging
 import os
@@ -30,11 +29,6 @@ class SubmitCommand(SquadClientCommand):
             help="Single result output (pass/fail/skip)",
             choices=["pass", "fail", "skip"],
         )
-        parser.add_argument(
-            "--results-layout",
-            help="Layout of the results file, if any",
-            choices=["tuxbuild"],
-        )
         parser.add_argument(
             "--metrics",
             help="File with metrics(benchmarsk) to submit. Max 5MB. JSON and YAML formats are supported",
@@ -95,48 +89,6 @@ class SubmitCommand(SquadClientCommand):
 
         return output_dict
 
-    def _load_tuxbuild(self, path):
-        if not self.__check_file(path):
-            return None
-
-        data = None
-        try:
-            with open(path) as f:
-                tb = {}
-                builds = json.load(f)
-
-                for b in builds:
-                    name = self._get_tuxbuild_test_name(b)
-                    tb[name] = b["build_status"]
-
-                data = tb
-
-        except IndexError as ie:
-            logger.error("Failed to load tuxbuild json due to a missing kconfig value: %s", ie)
-
-        except KeyError as ke:
-            logger.error("Failed to load tuxbuild json due to a missing variable: %s", ke)
-
-        except json.JSONDecodeError as jde:
-            logger.error("Failed to load json: %s", jde)
-
-        except OSError as ose:
-            logger.error("Failed to open file: %s", ose)
-
-        return data
-
-    def _get_tuxbuild_test_name(self, build):
-        suite = "build"
-
-        if len(build["kconfig"][1:]):
-            kconfig = "%s-%s" % (build["kconfig"][0], hashlib.sha1(json.dumps(build["kconfig"][1:]).encode()).hexdigest()[0:8])
-        else:
-            kconfig = build["kconfig"][0]
-
-        return "%s/%s-%s" % (
-            suite, build["toolchain"], kconfig,
-        )
-
     def run(self, args):
         results_dict = {}
         metrics_dict = {}
@@ -149,10 +101,7 @@ class SubmitCommand(SquadClientCommand):
             results_dict = {args.result_name: args.result_value}
 
         if args.results:
-            if args.results_layout == 'tuxbuild':
-                results_dict = self._load_tuxbuild(args.results)
-            else:
-                results_dict = self.__read_input_file(args.results)
+            results_dict = self.__read_input_file(args.results)
 
             if results_dict is None:
                 return False
